<?php
namespace Teknisa\COZ\Controllers;

use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\COZ\Services\RequisicaoPlanejamentoProducaoService;
use Teknisa\COZ\Controllers\GeracaoProdutoAcabadoController;

class Pla07010 extends \Zeedhi\Framework\Controller\Report {

    protected $entityManager;
    protected $birtStrategy;
    protected $geracaoController;
    protected $reqProducaoService;
    protected $reportName;
    protected $novoCodigo;
    protected $lista;

    public function __construct(
        $reportService, $entityManager, $birtStrategy, $novoCodigo,
        GeracaoProdutoAcabadoController $geracaoController,
        RequisicaoPlanejamentoProducaoService $reqProducaoService,
        $lista
    ) {
        $this->geracaoController  = $geracaoController;
        $this->reqProducaoService  = $reqProducaoService;
        $this->entityManager      = $entityManager;
        $this->birtStrategy       = $birtStrategy;
        $this->novoCodigo = $novoCodigo;
        $this->lista = $lista;

        parent::__construct($reportService);
    }

    protected $reportMapping = array (
        'gpa07000' =>
        array (
            'strategy' => 'BIRT',
            'parameterMapping' =>
            array (
                'P_CDCENTRAL' => 'P_CDCENTRAL',
                'P_DTPRODFIN' => 'P_DTPRODFIN',
                'P_DTCONSUMOFIN' => 'P_DTCONSUMOFIN',
                'P_LISTASERV' => 'P_LISTASERV',
                'P_TDTCONSUMO' => 'P_TDTCONSUMO',
                'P_DTPRODINI' => 'P_DTPRODINI',
                'P_DTCONSUMOINI' => 'P_DTCONSUMOINI',
                'P_LISTAPROD' => 'P_LISTAPROD',
                'P_NRPLANPROD' => 'P_NRPLANPROD',
                'NRORG' => 'P_NRORG',
                'P_CDPICTPROD' => 'P_CDPICTPROD'
            )
        ),
        'gpa07001' =>
        array (
            'strategy' => 'BIRT',
            'parameterMapping' =>
            array (
                'P_CDCENTRAL' => 'P_CDCENTRAL',
                'P_DTPRODFIN' => 'P_DTPRODFIN',
                'P_DTCONSUMOFIN' => 'P_DTCONSUMOFIN',
                'P_LISTASERV' => 'P_LISTASERV',
                'P_TDTCONSUMO' => 'P_TDTCONSUMO',
                'P_DTPRODINI' => 'P_DTPRODINI',
                'P_DTCONSUMOINI' => 'P_DTCONSUMOINI',
                'P_LISTAPROD' => 'P_LISTAPROD',
                'P_NRPLANPROD' => 'P_NRPLANPROD',
                'NRORG' => 'P_NRORG',
                'P_CDPICTPROD' => 'P_CDPICTPROD'
            )
        ),
        'gpa07002' =>
        array (
            'strategy' => 'BIRT',
            'parameterMapping' =>
            array (
                'P_CDCENTRAL' => 'P_CDCENTRAL',
                'P_DTPRODFIN' => 'P_DTPRODFIN',
                'P_DTPRODINI' => 'P_DTPRODINI',
                'P_LISTAPROD' => 'P_LISTAPROD',
                'P_NRLISTAETIQ' => 'P_NRLISTAETIQ',
                'P_GERAETQPARC' => 'P_GERAETQPARC',
                'P_NRPLANPROD' => 'P_NRPLANPROD',
                'NRORG' => 'P_NRORG'
            )
        ),
        'gpa07003' =>
        array (
            'strategy' => 'BIRT',
            'parameterMapping' =>
            array (
                'P_CDCENTRAL' => 'P_CDCENTRAL',
                'P_LISTAGERPARC' => 'P_LISTAGERPARC',
                'P_NRLISTAETIQ' => 'P_NRLISTAETIQ',
                'NRORG' => 'P_NRORG'
            )
        ),
        'gpa07004' =>
        array (
            'strategy' => 'BIRT',
            'parameterMapping' =>
            array (
                'P_CDCENTRAL' => 'P_CDCENTRAL',
                'P_DTPRODFIN' => 'P_DTPRODFIN',
                'P_DTPRODINI' => 'P_DTPRODINI',
                'P_NRPLANPROD' => 'P_NRPLANPROD',
                'P_CDPICTPROD' => 'P_CDPICTPROD',
                'P_CDSETOR' =>  'P_CDSETOR',
                'P_SUPRIMIRSETOR' => 'P_SUPRIMIRSETOR',
                'NRORG' => 'P_NRORG'
            )
        ),
        'gpa07005' =>
        array (
            'strategy' => 'BIRT',
            'parameterMapping' =>
            array (
                'P_CDCENTRAL' => 'P_CDCENTRAL',
                'P_DTPRODFIN' => 'P_DTPRODFIN',
                'P_DTPRODINI' => 'P_DTPRODINI',
                'P_NRPLANPROD' => 'P_NRPLANPROD',
                'P_CDPICTPROD' => 'P_CDPICTPROD',
                'P_CDSETOR' => 'P_CDSETOR',
                'P_SUPRIMIRSETOR' => 'P_SUPRIMIRSETOR',
                'NRORG' => 'P_NRORG'
            )
        )
    );

     public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $this->reportName = $row['__report_name'];
        
        $row['NRORG'] = $this->geracaoController->environment->getNrorgTrab();
        $nrorg = $row['NRORG'];
        
        if(empty($row['P_SUPRIMIRSETOR'])) $row['P_SUPRIMIRSETOR'] = 'N';
        
        if(array_key_exists('P_CDSETOR', $row) && $row['P_CDSETOR'] != 'T') $row['P_CDSETOR'] = $this->lista->geraLista($row['P_CDSETOR'], $row['NRORG']);

        if($this->reportName == 'gpa07000' || $this->reportName == 'gpa07001'){
            $nrlista = $this->novoCodigo->getCodeByTableName('LISTA_SERVICO', $nrorg);
            
            foreach($row['P_LISTASERV'] as $item){
                $cdfilial = substr($item, 0, 4);
                $cdservfili = substr($item, 4, 9);
                $this->reqProducaoService->geraListaServico($nrorg, $cdfilial, $cdservfili, $nrlista);
            }
            $row['P_LISTASERV'] = $nrlista;
        }
        $this->birtStrategy->setReportFormat(strtolower($row['QR2TYPE']));
        
    }
}